==> archiva-model-1.1-sources.jar: org/apache/maven/archiva/model/Plugin.java <==
/*
 * $Id$
 */

package org.apache.maven.archiva.model;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * The Plugin
 * 
 * @version $Revision$ $Date$
 */
public class Plugin implements java.io.Serializable {


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field prefix
     */
    private String prefix;

    /**
     * Field artifactId
     */
    private String artifactId;

    /**
     * Field name
     */
    private String name;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Method equals
     * 
     * @param other
     */
    public boolean equals(Object other)
    {
        if ( this == other)
        {
            return true;
        }
        
        if ( !(other instanceof Plugin) )
        {
            return false;
        }
        
        Plugin that = (Plugin) other;
        boolean result = true;
        result = result && ( getArtifactId() == null ? that.getArtifactId() == null : getArtifactId().equals( that.getArtifactId() ) );
        return result;
    } //-- boolean equals(Object) 

    /**
     * Get 
     *             The artifactId for a plugin
     *           
     */
    public String getArtifactId()
    {
        return this.artifactId;
    } //-- String getArtifactId() 

    /**
     * Get 
     *             The name for a plugin
     *           
     */
    public String getName()
    {
        return this.name;
    } //-- String getName() 

    /**
     * Get 
     *             The prefix for a plugin
     *           
     */
    public String getPrefix()
    {
        return this.prefix;
    } //-- String getPrefix() 

    /**
     * Method hashCode
     */
    public int hashCode()
    {
        int result = 17;
        long tmp;
        result = 37 * result + ( artifactId != null ? artifactId.hashCode() : 0 );
        return result;
    } //-- int hashCode() 

    /**
     * Set 
     *             The artifactId for a plugin
     *           
     * 
     * @param artifactId
     */
    public void setArtifactId(String artifactId)
    {
        this.artifactId = artifactId;
    } //-- void setArtifactId(String) 

    /**
     * Set 
     *             The name for a plugin
     *           
     * 
     * @param name
     */
    public void setName(String name)
    {
        this.name = name;
    } //-- void setName(String) 

    /**
     * Set 
     *             The prefix for a plugin
     *           
     * 
     * @param prefix
     */
    public void setPrefix(String prefix)
    {
        this.prefix = prefix;
    } //-- void setPrefix(String) 

    /**
     * Method toString
     */
    public java.lang.String toString()
    {
        StringBuffer buf = new StringBuffer();
        buf.append( "artifactId = '" );
        buf.append( getArtifactId() + "'" );
        return buf.toString();
    } //-- java.lang.String toString() 


    private String modelEncoding = "UTF-8";

    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    public String getModelEncoding()
    {
        return modelEncoding;
    }
}

==> archiva-model-1.3.3-sources.jar: org/apache/maven/archiva/model/Plugin.java <==
/*
 * $Id$
 */

package org.apache.maven.archiva.model;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.Date;

/**
 * The Plugin.
 * 
 * @version $Revision$ $Date$
 */
public class Plugin
    implements java.io.Serializable
{

      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * 
     *             The prefix for a plugin
     *           .
     */
    private String prefix;

    /**
     * 
     *             The artifactId for a plugin
     *           .
     */
    private String artifactId;

    /**
     * 
     *             The name for a plugin
     *           .
     */
    private String name;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Method equals.
     * 
     * @param other
     * @return boolean
     */
    public boolean equals( Object other )
    {
        if ( this == other )
        {
            return true;
        }

        if ( !( other instanceof Plugin ) )
        {
            return false;
        }

        Plugin that = (Plugin) other;
        boolean result = true;

        result = result && ( getArtifactId() == null ? that.getArtifactId() == null : getArtifactId().equals( that.getArtifactId() ) );

        return result;
    } //-- boolean equals( Object )

    /**
     * Get 
     *             The artifactId for a plugin
     *           .
     * 
     * @return String
     */
    public String getArtifactId()
    {
        return this.artifactId;
    } //-- String getArtifactId()

    /**
     * Get 
     *             The name for a plugin
     *           .
     * 
     * @return String
     */
    public String getName()
    {
        return this.name;
    } //-- String getName()

    /**
     * Get 
     *             The prefix for a plugin
     *           .
     * 
     * @return String
     */
    public String getPrefix()
    {
        return this.prefix;
    } //-- String getPrefix()

    /**
     * Method hashCode.
     * 
     * @return int
     */
    public int hashCode()
    {
        int result = 17;

        result = 37 * result + ( artifactId != null ? artifactId.hashCode() : 0 );

        return result;
    } //-- int hashCode()

    /**
     * Set 
     *             The artifactId for a plugin
     *           .
     * 
     * @param artifactId
     */
    public void setArtifactId( String artifactId )
    {
        this.artifactId = artifactId;
    } //-- void setArtifactId( String )

    /**
     * Set 
     *             The name for a plugin
     *           .
     * 
     * @param name
     */
    public void setName( String name )
    {
        this.name = name;
    } //-- void setName( String )

    /**
     * Set 
     *             The prefix for a plugin
     *           .
     * 
     * @param prefix
     */
    public void setPrefix( String prefix )
    {
        this.prefix = prefix;
    } //-- void setPrefix( String )

    /**
     * Method toString.
     * 
     * @return String
     */
    public java.lang.String toString()
    {
        StringBuffer buf = new StringBuffer();

        buf.append( "artifactId = '" );
        buf.append( getArtifactId() );
        buf.append( "'" );

        return buf.toString();
    } //-- java.lang.String toString()


}
